@@ -86,6 +86,8 @@ public:
 
     /** Name of the operator running this line. */
     KPUBLICTRANSPORT_PROPERTY(QString, operatorName, setOperatorName)
+    /** URL to e.g. a website of the operator of this line. */
+    KPUBLICTRANSPORT_PROPERTY(QUrl, operatorUrl, setOperatorUrl)
 
     /** Generic icon for the line mode.
      *  @see modeIconName(Line::Mode)
@@ -138,11 +140,18 @@ public:
 
     /** Serializes one object to JSON. */
     [[nodiscard]] static QJsonObject toJson(const Line &l);
+    /** Serializes a list of object to JSON. */
+    [[nodiscard]] static QJsonArray toJson(const std::vector<Line> &l);
     /** Deserialize an object from JSON.
      *  @note Line meta data isn't serialized, so you might need to call applyLineMetaData() again
      *  after loading a line.
      */
     [[nodiscard]] static Line fromJson(const QJsonObject &obj);
+    /** Deserialize a list of objects from JSON.
+     *  @note Line meta data isn't serialized, so you might need to call applyLineMetaData() again
+     *  after loading a line.
+     */
+    [[nodiscard]] static std::vector<Line> fromJson(const QJsonArray &array);
 };
 
 class RoutePrivate;
